<?php

/**
 * @file
 * Custom theme implementation to display a single Drupal page.
 *
 * The doctype, html, head and body tags are not in this template. Instead they
 * can be found in the html.tpl.php template in this directory.
 *
 * Available variables:
 *
 * General utility variables:
 * - $base_path: The base URL path of the Drupal installation. At the very
 *   least, this will always default to /.
 * - $directory: The directory the template is located in, e.g. modules/system
 *   or themes/bartik.
 * - $is_front: TRUE if the current page is the front page.
 * - $logged_in: TRUE if the user is registered and signed in.
 * - $is_admin: TRUE if the user has permission to access administration pages.
 *
 * Site identity:
 * - $front_page: The URL of the front page. Use this instead of $base_path,
 *   when linking to the front page. This includes the language domain or
 *   prefix.
 * - $logo: The path to the logo image, as defined in theme configuration.
 * - $site_name: The name of the site, empty when display has been disabled
 *   in theme settings.
 * - $site_slogan: The slogan of the site, empty when display has been disabled
 *   in theme settings.
 *
 * Navigation:
 * - $main_menu (array): An array containing the Main menu links for the
 *   site, if they have been configured.
 * - $secondary_menu (array): An array containing the Secondary menu links for
 *   the site, if they have been configured.
 *
 * Page content (in order of occurrence in the default page.tpl.php):
 * - $title_prefix (array): An array containing additional output populated by
 *   modules, intended to be displayed in front of the main title tag that
 *   appears in the template.
 * - $title: The page title, for use in the actual HTML content.
 * - $title_suffix (array): An array containing additional output populated by
 *   modules, intended to be displayed after the main title tag that appears in
 *   the template.
 * - $messages: HTML for status and error messages. Should be displayed
 *   prominently.
 * - $tabs (array): Tabs linking to any sub-pages beneath the current page
 *   (e.g., the view and edit tabs when displaying a node).
 * - $action_links (array): Actions local to the page, such as 'Add menu' on the
 *   menu administration interface.
 * - $feed_icons: A string of all feed icons for the current page.
 * - $node: The node object, if there is an automatically-loaded node
 *   associated with the page, and the node ID is the second argument
 *   in the page's path (e.g. node/12345 and node/12345/revisions, but not
 *   comment/reply/12345).
 *
 * Regions:
 * - $page['help']: Dynamic help text, mostly for admin pages.
 * - $page['highlighted']: Items for the highlighted content region.
 * - $page['content']: The main content of the current page.
 * - $page['sidebar_first']: Items for the first sidebar.
 * - $page['sidebar_second']: Items for the second sidebar.
 * - $page['header']: Items for the header region.
 * - $page['footer']: Items for the footer region.
 *
 * @see template_preprocess()
 * @see template_preprocess_page()
 * @see template_process()
 * @see html.tpl.php
 *
 * @ingroup themeable
 *
 * @package Valencia
 * @since 1.0.0
 */
?>
        <header class="banner global" role="banner">
            <nav class="nav-primary" role="navigation">
                <?php print theme('links__system_main_menu', array(
                    'links' => $valencia_menu,
                    'id'    => 'header'
                ));?>
                <div class="site-name">
                    <a class="logo-ubuntuit" href="<?php print $front_page; ?>">
                        <span>ubuntu-it</span>
                    </a>
                </div>
            </nav>
        </header>

        <header class="banner global inverted" role="banner">
            <nav class="nav-primary nav-left" role="navigation">
                <?php print theme('links__system_main_menu', array(
                    'links' => $valencia_menu,
                    'id'    => 'subheader'
                ));?>
                <form action="/search" id="search-form" class="header-search">
                    <input type="search" maxlength="255" name="q" id="edit-keys" class="form-text" placeholder="Cerca&hellip;" value="" />
                    <button type="submit">
                        <img src="http://assets.ubuntu.com/sites/ubuntu/1044/u/img/search-black.svg" alt="Search" height="28" />
                    </button>
                </form>
            </nav>
        </header>

        <div class="wrapper">
            <div id="main-content" class="inner-wrapper">

                <?php print $messages; // Error messages ?>

                <nav role="navigation" class="nav-secondary clearfix">
                    <?php print theme('links__system_main_menu', array(
                        'links' => $valencia_menu,
                        'id'    => 'breadcrumb'
                    ));?>
                </nav>

                <div id="main-wrapper">
                    <div id="main" class="clearfix">
                        <div id="content" class="column">
                            <div class="section">
                                <a id="main-content"></a>
                                <?php if ($title): ?><h1 class="row" id="page-title"><?php print $title; ?></h1><?php endif; ?>
                                <?php if ($tabs): ?><div class="tabs"><?php print render($tabs); ?></div><?php endif; ?>
                                <?php print render($page['help']); ?>
                                <?php if ($action_links): ?><ul class="action-links"><?php print render($action_links); ?></ul><?php endif; ?>
                                <?php print render($page['content']); ?>
                                <?php print $feed_icons; ?>
                            </div>
                        </div>
                    </div>
                </div>

            </div>
        </div>

        <footer class="global clearfix">
            <nav role="navigation">
                <div class="footer-a">
                    <div class="clearfix">
                        <?php print theme('links__system_main_menu', array(
                            'links' => $valencia_menu,
                            'id'    => 'footer'
                        ));?>
                    </div>
                </div>
                <div class="legal clearfix">
                    <p class="twelve-col">&copy; Ubuntu e Canonical sono marchi registrati da Canonical Ltd.</p>
                    <p class="twelve-col">
                        Sito realizzato con &hearts; dal Gruppo Web di ubuntu-it, con <a href="http://drupal.org" target="_blank">Drupal</a> e <a href="http://www.postgresql.org/" target="_blank">PostgreSQL</a>.
                    </p>
                    <p class="twelve-col"><a href="http://code.ubuntu-it.org/ubuntu-it-web/valencia/issues" target="_blank">Segnala un errore</a> &nbsp;&bull;&nbsp; <a href="http://code.ubuntu-it.org/ubuntu-it-web/www-test" target="_blank">Scarica il codice</a> &nbsp;&bull;&nbsp; <a href="http://wiki.ubuntu-it.org/GruppoWeb/Contribuire" target="_blank">Collabora con noi</a>
                </div>
                <span class="accessibility-aid"><a href="#">Got to the top of the page</a></span>
            </nav>
        </footer>
